@@ -31,7 +31,7 @@ import time
 import base64
 from functools import wraps
 
-VERSION = '1.29'
+VERSION = '1.30'
 
 def login_required(func):
     @wraps(func)
@@ -81,7 +81,7 @@ class MetroClient(object):
         self.__manage_url = '{0}/manage'.format(self.__api_url)
         self.__version = VERSION
         self._authenticated = False
-        ca_certs = os.path.join(os.path.dirname(__file__), 'cacerts.txt')
+        ca_certs = os.path.join(os.path.dirname(__file__), 'metrocerts.txt')
         self._http = httplib2.Http(ca_certs=ca_certs)
         # add startssl ca
         self._headers = {
